@@ -1,6 +1,6 @@
 package Net::Prober::Probe::HTTP;
 {
-  $Net::Prober::Probe::HTTP::VERSION = '0.14';
+  $Net::Prober::Probe::HTTP::VERSION = '0.15';
 }
 
 use strict;
@@ -58,7 +58,8 @@ sub _prepare_request {
             $port ||= 443;
         }
     }
-    elsif (defined $port) {
+
+    if (defined $port) {
         $scheme = $port == 443 ? "https" : "http";
     }
 
@@ -186,7 +187,7 @@ Net::Prober::Probe::HTTP
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 AUTHOR
 
@@ -194,7 +195,7 @@ Cosimo Streppone <cosimo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Cosimo Streppone.
+This software is copyright (c) 2016 by Cosimo Streppone.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
